# py-link-monitor
Link monitor written on Python that uses command line ping utility
# Installation
pip install py-link-monitor
# Usage
$ py_link_monitor -t 8.8.8.8
# Sample output
monitor Status changed to ALIVE for monitor of 8.8.8.8 at 2023-05-16T15:51:15.184630
monitor Status changed to FAIL for monitor of 8.8.8.8 at 2023-05-16T15:52:21.319762
monitor Status changed to ALIVE for monitor of 8.8.8.8 at 2023-05-16T15:52:26.512260
